@@ -315,11 +315,21 @@ class VisualizationSet(_VisualizationBase):
             self._calculate_min_max()
         return self._max_point
 
-    def add_geometry(self, geometry, insert_index=None):
-        """Add a data set to this AnalysisGeometry object.
+    def add_vis_set(self, vis_set):
+        """Add all geometry objects of another VisualizationSet to this one.
 
         Args:
-            data: A VisualizationData object to be added to this AnalysisGeometry.
+            vis_set: A VisualizationData object to be added to this AnalysisGeometry.
+        """
+        for geo in vis_set.geometry:
+            self.add_geometry(geo)
+
+    def add_geometry(self, geometry, insert_index=None):
+        """Add a ContextGeometry or AnalysisGeometry object to this VisualizationSet.
+
+        Args:
+            geometry: A ContextGeometry or AnalysisGeometry object to be added
+                to this VisualizationSet.
             insert_index: An integer for the index at which the data should be
                 inserted. If None, the data will be appended to the end. (Default: None).
         """
@@ -443,7 +453,9 @@ class VisualizationSet(_VisualizationBase):
         # create dictionary from the VisualizationSet
         vs_dict = self.to_dict()
         # set up a name and folder for the JSON
-        file_name = name if name.lower().endswith('.json') else '{}.json'.format(name)
+        nl = name.lower()
+        file_name = name if nl.endswith('.vsf') or nl.endswith('.json') \
+            else '{}.vsf'.format(name)
         if not os.path.isdir(folder):
             os.makedirs(folder)
         vs_file = os.path.join(folder, file_name)
@@ -463,9 +475,9 @@ class VisualizationSet(_VisualizationBase):
         # create dictionary from the VisualizationSet
         vs_dict = self.to_dict()
         # set up a name and folder for the pkl
-        if name is None:
-            name = self.identifier
-        file_name = name if name.lower().endswith('.pkl') else '{}.pkl'.format(name)
+        nl = name.lower()
+        file_name = name if nl.endswith('.vsf') or nl.endswith('.pkl') \
+            else '{}.vsf'.format(name)
         if not os.path.isdir(folder):
             os.makedirs(folder)
         vs_file = os.path.join(folder, file_name)
